pub struct LibCfg {
pub scheme_sync_default: String,
pub scheme: Vec<Scheme>,
pub tmpl_html: TmplHtml,
}Expand description
Processed configuration data.
Its structure is different form the input form defined in LibCfgRaw (see
example in LIB_CONFIG_DEFAULT_TOML).
For conversion use:
use tpnote_lib::config::LIB_CONFIG_DEFAULT_TOML;
use tpnote_lib::config::LibCfg;
use tpnote_lib::config_value::CfgVal;
use std::str::FromStr;
let cfg_val = CfgVal::from_str(LIB_CONFIG_DEFAULT_TOML).unwrap();
// Run test.
let lib_cfg = LibCfg::try_from(cfg_val).unwrap();
// Check.
assert_eq!(lib_cfg.scheme_sync_default, "default")Fields
scheme_sync_default: StringThe fallback scheme for the sync_filename template choice, if the
scheme header variable is empty or is not defined.
scheme: Vec<Scheme>Configuration of Scheme.
tmpl_html: TmplHtmlConfiguration of HTML templates.
Implementations
Sourceimpl LibCfg
impl LibCfg
Sourcepub fn scheme_idx(&self, name: &str) -> Result<usize, LibCfgError>
pub fn scheme_idx(&self, name: &str) -> Result<usize, LibCfgError>
Returns the index of a named scheme. If no scheme with that name can be
found, return LibCfgError::SchemeNotFound.
Sourcepub fn assert_validity(&self) -> Result<(), LibCfgError>
pub fn assert_validity(&self) -> Result<(), LibCfgError>
Perform some semantic consistency checks.
sort_tag.extra_separatormust NOT be insort_tag.extra_chars.sort_tag.extra_separatormust NOT be in0..9.sort_tag.extra_separatormust NOT be ina..z.sort_tag.extra_separatormust NOT be insort_tag.extra_chars.sort_tag.extra_separatormust NOTFILENAME_DOTFILE_MARKER.copy_counter.extra_separatormust be one ofsanitize_filename_reader_friendly::TRIM_LINE_CHARS.- All characters of
sort_tag.separatormust be insort_tag.extra_chars. sort_tag.separatormust start with NOTFILENAME_DOTFILE_MARKER.