TemplateKind

Enum TemplateKind 

#[non_exhaustive]
pub enum TemplateKind { FromDir, FromTextFile, AnnotateFile, SyncFilename, None, }
Each workflow is related to one TemplateKind, which relates to one content template and one filename template.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


FromDir

Templates used when Tp-Note is invoked with a directory path. Clipboard data may be available.



FromTextFile

Templates used when Tp-Note is invoked with a path pointing to a text file that does not contain a YAML header.



AnnotateFile

Templates used when Tp-Note is invoked with a path pointing to a non text file.



SyncFilename

Templates used when Tp-Note is invoked with a path pointing to a Tp-Note text file with a valid YAML header (with a title: field).



None

No templates are used, but the file is still parsed in order to render it later to HTML (cf. <Note>.render_content_to_html().

Implementations

Source

impl TemplateKind

pub fn from<T: Content>(path: &Path) -> (Self, Option<T>)

A constructor returning the tuple (template_kind, Some(content)). template_kind is the result of the logic calculating under what circumstances what template should be used. If path has a Tp-Note extension (e.g. .md) and the file indicated by path could be opened and loaded from disk, Some(content) contains its content. Otherwise None is returned.

pub fn get_content_template(&self) -> String

Returns the content template string as it is defined in the configuration file. Panics for TemplateKind::SyncFilename and TemplateKind::None.

pub fn get_content_template_name(&self) -> &str

Returns the content template variable name as it is used in the configuration file.

pub fn get_filename_template(&self) -> String

Returns the file template string as it is defined in the configuration file. Panics for TemplateKind::None.

pub fn get_filename_template_name(&self) -> &str

Returns the content template variable name as it is used in the configuration file.